@@ -67,19 +67,19 @@ use FindBin qw($Bin);
 use File::Find;
 use Config;
 
-use vars qw( $VERSION $PERL $COVERAGE_THRESHOLD $COVER $UNTAINT_PATTERN $PERL_PATTERN $CAN_USE_WARNINGS $TEST_SYNTAX $TEST_STRICT $TEST_WARNINGS $TEST_SKIP $DEVEL_COVER_OPTIONS $DEVEL_COVER_DB @MODULES_ENABLING_STRICT @MODULES_ENABLING_WARNINGS );
-$VERSION = '0.24';
-$PERL    = $^X || 'perl';
-$COVERAGE_THRESHOLD = 50; # 50%
-$UNTAINT_PATTERN    = qr|^(.*)$|;
-$PERL_PATTERN       = qr/^#!.*perl/;
-$CAN_USE_WARNINGS   = ($] >= 5.006);
-$TEST_SYNTAX   = 1;  # Check compile
-$TEST_STRICT   = 1;  # Check use strict;
-$TEST_WARNINGS = 0;  # Check use warnings;
-$TEST_SKIP     = []; # List of files to skip check
-$DEVEL_COVER_OPTIONS = '+ignore,".Test.Strict\b"';
-$DEVEL_COVER_DB      = 'cover_db';
+our $COVER;
+our $VERSION = '0.28';
+our $PERL    = $^X || 'perl';
+our $COVERAGE_THRESHOLD = 50; # 50%
+our $UNTAINT_PATTERN    = qr|^(.*)$|;
+our $PERL_PATTERN       = qr/^#!.*perl/;
+our $CAN_USE_WARNINGS   = ($] >= 5.006);
+our $TEST_SYNTAX   = 1;  # Check compile
+our $TEST_STRICT   = 1;  # Check use strict;
+our $TEST_WARNINGS = 0;  # Check use warnings;
+our $TEST_SKIP     = []; # List of files to skip check
+our $DEVEL_COVER_OPTIONS = '+ignore,".Test.Strict\b"';
+our $DEVEL_COVER_DB      = 'cover_db';
 my $IS_WINDOWS = $^O =~ /MSwin/i;
 
 my $Test  = Test::Builder->new;
@@ -228,6 +228,9 @@ sub _strict_ok {
         return 1;
       }
     }
+    if (/\buse\s+(5.01\d+)/ and $1 >= 5.012) {
+      return 1;
+    }
   }
   return;
 }
@@ -241,7 +244,7 @@ List taken from https://metacpan.org/pod/Module::CPANTS::Kwalitee::Uses v95
 
 =cut
 
-@MODULES_ENABLING_STRICT = qw(
+our @MODULES_ENABLING_STRICT = qw(
   strict
   Any::Moose
   Catmandu::Sane
@@ -282,7 +285,7 @@ List taken from https://metacpan.org/pod/Module::CPANTS::Kwalitee::Uses v95
 
 =cut
 
-@MODULES_ENABLING_WARNINGS = qw(
+our @MODULES_ENABLING_WARNINGS = qw(
   warnings
   Any::Moose
   Catmandu::Sane
@@ -354,7 +357,7 @@ sub _warnings_ok {
   my ($is_script, $in) = @_;
   while (<$in>) {
     if ($. == 1 and $is_script and $_ =~ $PERL_PATTERN) {
-      if (/perl\s+\-\w*[wW]/) {
+      if (/\s+-\w*[wW]/) {
         return 1;
       }
     }
@@ -500,7 +503,6 @@ sub _taint_switch {
 ##
 sub _module_to_path {
   my $file = shift;
-  return $file unless ($file =~ /::/);
   my @parts = split /::/, $file;
   my $module = File::Spec->catfile(@parts) . '.pm';
   foreach my $dir (@INC) {
